==> igniteui-angular-core-17.3.0.tgz: package/esm2015/lib/CustomPaletteBrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { CustomPaletteBrushScaleDescription } from "./CustomPaletteBrushScaleDescription";
/**
 * @hidden
 */
export let CustomPaletteBrushScaleDescriptionMetadata = /*@__PURE__*/ (() => {
    class CustomPaletteBrushScaleDescriptionMetadata extends Base {
        static b(a) {
            if (CustomPaletteBrushScaleDescriptionMetadata.a == null) {
                CustomPaletteBrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CustomPaletteBrushScaleDescriptionMetadata.c(CustomPaletteBrushScaleDescriptionMetadata.a);
            }
            if (a.k(CustomPaletteBrushScaleDescriptionMetadata.a)) {
                return;
            }
            a.ab(CustomPaletteBrushScaleDescriptionMetadata.a);
        }
        static c(a) {
            BrushScaleDescriptionMetadata.c(a);
            a.item("BrushSelectionMode", "ExportedType:string:BrushSelectionMode");
            a.item("BrushSelectionMode@names", "Select;Interpolate");
        }
        static d(a) {
            CustomPaletteBrushScaleDescriptionMetadata.b(a);
            a.ad("CustomPaletteBrushScale", () => new CustomPaletteBrushScaleDescription());
            a.ac("CustomPaletteBrushScale", CustomPaletteBrushScaleDescriptionMetadata.a);
        }
    }
    CustomPaletteBrushScaleDescriptionMetadata.$t = markType(CustomPaletteBrushScaleDescriptionMetadata, 'CustomPaletteBrushScaleDescriptionMetadata');
    CustomPaletteBrushScaleDescriptionMetadata.a = null;
    return CustomPaletteBrushScaleDescriptionMetadata;
})();

==> igniteui-angular-core-20.0.0.tgz: package/esm2015/lib/CustomPaletteBrushScaleDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { BrushScaleDescriptionMetadata } from "./BrushScaleDescriptionMetadata";
import { CustomPaletteBrushScaleDescription } from "./CustomPaletteBrushScaleDescription";
/**
 * @hidden
 */
export let CustomPaletteBrushScaleDescriptionMetadata = /*@__PURE__*/ (() => {
    class CustomPaletteBrushScaleDescriptionMetadata extends Base {
        static b(a) {
            if (CustomPaletteBrushScaleDescriptionMetadata.a == null) {
                CustomPaletteBrushScaleDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                CustomPaletteBrushScaleDescriptionMetadata.c(CustomPaletteBrushScaleDescriptionMetadata.a);
            }
            if (a.k(CustomPaletteBrushScaleDescriptionMetadata.a)) {
                return;
            }
            a.ac(CustomPaletteBrushScaleDescriptionMetadata.a);
        }
        static c(a) {
            BrushScaleDescriptionMetadata.c(a);
            a.item("BrushSelectionMode", "ExportedType:string:BrushSelectionMode");
            a.item("BrushSelectionMode@names", "Select;Interpolate");
        }
        static d(a) {
            CustomPaletteBrushScaleDescriptionMetadata.b(a);
            a.ae("CustomPaletteBrushScale", () => new CustomPaletteBrushScaleDescription());
            a.ad("CustomPaletteBrushScale", CustomPaletteBrushScaleDescriptionMetadata.a);
        }
    }
    CustomPaletteBrushScaleDescriptionMetadata.$t = markType(CustomPaletteBrushScaleDescriptionMetadata, 'CustomPaletteBrushScaleDescriptionMetadata');
    CustomPaletteBrushScaleDescriptionMetadata.a = null;
    return CustomPaletteBrushScaleDescriptionMetadata;
})();
